# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class ActorSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'num_total_actors': 'int',
        'num_dependencies_unready_actors': 'int',
        'num_pending_creation_actors': 'int',
        'num_alive_actors': 'int',
        'num_restarting_actors': 'int',
        'num_dead_actors': 'int'
    }

    attribute_map = {
        'num_total_actors': 'num_total_actors',
        'num_dependencies_unready_actors': 'num_dependencies_unready_actors',
        'num_pending_creation_actors': 'num_pending_creation_actors',
        'num_alive_actors': 'num_alive_actors',
        'num_restarting_actors': 'num_restarting_actors',
        'num_dead_actors': 'num_dead_actors'
    }

    def __init__(self, num_total_actors=None, num_dependencies_unready_actors=None, num_pending_creation_actors=None, num_alive_actors=None, num_restarting_actors=None, num_dead_actors=None, local_vars_configuration=None):  # noqa: E501
        """ActorSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._num_total_actors = None
        self._num_dependencies_unready_actors = None
        self._num_pending_creation_actors = None
        self._num_alive_actors = None
        self._num_restarting_actors = None
        self._num_dead_actors = None
        self.discriminator = None

        self.num_total_actors = num_total_actors
        self.num_dependencies_unready_actors = num_dependencies_unready_actors
        self.num_pending_creation_actors = num_pending_creation_actors
        self.num_alive_actors = num_alive_actors
        self.num_restarting_actors = num_restarting_actors
        self.num_dead_actors = num_dead_actors

    @property
    def num_total_actors(self):
        """Gets the num_total_actors of this ActorSummary.  # noqa: E501


        :return: The num_total_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_total_actors

    @num_total_actors.setter
    def num_total_actors(self, num_total_actors):
        """Sets the num_total_actors of this ActorSummary.


        :param num_total_actors: The num_total_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_total_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_total_actors`, must not be `None`")  # noqa: E501

        self._num_total_actors = num_total_actors

    @property
    def num_dependencies_unready_actors(self):
        """Gets the num_dependencies_unready_actors of this ActorSummary.  # noqa: E501


        :return: The num_dependencies_unready_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_dependencies_unready_actors

    @num_dependencies_unready_actors.setter
    def num_dependencies_unready_actors(self, num_dependencies_unready_actors):
        """Sets the num_dependencies_unready_actors of this ActorSummary.


        :param num_dependencies_unready_actors: The num_dependencies_unready_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_dependencies_unready_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_dependencies_unready_actors`, must not be `None`")  # noqa: E501

        self._num_dependencies_unready_actors = num_dependencies_unready_actors

    @property
    def num_pending_creation_actors(self):
        """Gets the num_pending_creation_actors of this ActorSummary.  # noqa: E501


        :return: The num_pending_creation_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_pending_creation_actors

    @num_pending_creation_actors.setter
    def num_pending_creation_actors(self, num_pending_creation_actors):
        """Sets the num_pending_creation_actors of this ActorSummary.


        :param num_pending_creation_actors: The num_pending_creation_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_pending_creation_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_pending_creation_actors`, must not be `None`")  # noqa: E501

        self._num_pending_creation_actors = num_pending_creation_actors

    @property
    def num_alive_actors(self):
        """Gets the num_alive_actors of this ActorSummary.  # noqa: E501


        :return: The num_alive_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_alive_actors

    @num_alive_actors.setter
    def num_alive_actors(self, num_alive_actors):
        """Sets the num_alive_actors of this ActorSummary.


        :param num_alive_actors: The num_alive_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_alive_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_alive_actors`, must not be `None`")  # noqa: E501

        self._num_alive_actors = num_alive_actors

    @property
    def num_restarting_actors(self):
        """Gets the num_restarting_actors of this ActorSummary.  # noqa: E501


        :return: The num_restarting_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_restarting_actors

    @num_restarting_actors.setter
    def num_restarting_actors(self, num_restarting_actors):
        """Sets the num_restarting_actors of this ActorSummary.


        :param num_restarting_actors: The num_restarting_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_restarting_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_restarting_actors`, must not be `None`")  # noqa: E501

        self._num_restarting_actors = num_restarting_actors

    @property
    def num_dead_actors(self):
        """Gets the num_dead_actors of this ActorSummary.  # noqa: E501


        :return: The num_dead_actors of this ActorSummary.  # noqa: E501
        :rtype: int
        """
        return self._num_dead_actors

    @num_dead_actors.setter
    def num_dead_actors(self, num_dead_actors):
        """Sets the num_dead_actors of this ActorSummary.


        :param num_dead_actors: The num_dead_actors of this ActorSummary.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and num_dead_actors is None:  # noqa: E501
            raise ValueError("Invalid value for `num_dead_actors`, must not be `None`")  # noqa: E501

        self._num_dead_actors = num_dead_actors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActorSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ActorSummary):
            return True

        return self.to_dict() != other.to_dict()



import click
from rich import print as rprint
import tabulate

import anyscale
from anyscale.cli_logger import BlockLogger
from anyscale.commands import command_examples
from anyscale.commands.util import AnyscaleCommand


log = BlockLogger()


@click.group("user-group", help="Manage user groups.")
def user_group_cli() -> None:
    pass


@user_group_cli.command(
    name="list", cls=AnyscaleCommand, example=command_examples.USER_GROUP_LIST_EXAMPLE,
)
@click.option(
    "--max-items",
    default=50,
    type=int,
    help="Maximum number of user groups to return.",
)
def list_user_groups(max_items: int) -> None:
    """
    List user groups in the organization.
    """
    try:
        user_groups = anyscale.user_group.list(max_items=max_items)
    except ValueError as e:
        log.error(str(e))
        return

    if not user_groups:
        log.info("No user groups found.")
        return

    table = tabulate.tabulate(
        [(ug.id, ug.name) for ug in user_groups], headers=["ID", "Name"],
    )
    rprint(table)


@user_group_cli.command(
    name="get", cls=AnyscaleCommand, example=command_examples.USER_GROUP_GET_EXAMPLE,
)
@click.option(
    "--id", required=True, type=str, help="The ID of the user group to retrieve.",
)
def get_user_group(id: str) -> None:  # noqa: A002
    """
    Get a specific user group by ID.
    """
    try:
        user_group = anyscale.user_group.get(id=id)
    except ValueError as e:
        log.error(f"Failed to get user group: {e}")
        return

    details = [
        ("ID", user_group.id),
        ("Name", user_group.name),
        ("Organization ID", user_group.org_id),
        ("Created At", user_group.created_at.strftime("%Y-%m-%d %H:%M:%S UTC")),
        ("Updated At", user_group.updated_at.strftime("%Y-%m-%d %H:%M:%S UTC")),
    ]
    table = tabulate.tabulate(details, tablefmt="plain")
    rprint(table)



# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class SchedulerInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'requests': 'list[RequestStateInfo]',
        'machines': 'list[MachineStateInfo]',
        'recent_launch_failures': 'list[MachineLaunchFailure]'
    }

    attribute_map = {
        'requests': 'requests',
        'machines': 'machines',
        'recent_launch_failures': 'recent_launch_failures'
    }

    def __init__(self, requests=None, machines=None, recent_launch_failures=None, local_vars_configuration=None):  # noqa: E501
        """SchedulerInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._requests = None
        self._machines = None
        self._recent_launch_failures = None
        self.discriminator = None

        self.requests = requests
        self.machines = machines
        self.recent_launch_failures = recent_launch_failures

    @property
    def requests(self):
        """Gets the requests of this SchedulerInfo.  # noqa: E501

        Current request states.  # noqa: E501

        :return: The requests of this SchedulerInfo.  # noqa: E501
        :rtype: list[RequestStateInfo]
        """
        return self._requests

    @requests.setter
    def requests(self, requests):
        """Sets the requests of this SchedulerInfo.

        Current request states.  # noqa: E501

        :param requests: The requests of this SchedulerInfo.  # noqa: E501
        :type: list[RequestStateInfo]
        """
        if self.local_vars_configuration.client_side_validation and requests is None:  # noqa: E501
            raise ValueError("Invalid value for `requests`, must not be `None`")  # noqa: E501

        self._requests = requests

    @property
    def machines(self):
        """Gets the machines of this SchedulerInfo.  # noqa: E501

        Current machine states.  # noqa: E501

        :return: The machines of this SchedulerInfo.  # noqa: E501
        :rtype: list[MachineStateInfo]
        """
        return self._machines

    @machines.setter
    def machines(self, machines):
        """Sets the machines of this SchedulerInfo.

        Current machine states.  # noqa: E501

        :param machines: The machines of this SchedulerInfo.  # noqa: E501
        :type: list[MachineStateInfo]
        """
        if self.local_vars_configuration.client_side_validation and machines is None:  # noqa: E501
            raise ValueError("Invalid value for `machines`, must not be `None`")  # noqa: E501

        self._machines = machines

    @property
    def recent_launch_failures(self):
        """Gets the recent_launch_failures of this SchedulerInfo.  # noqa: E501

        Recent launch failures.  # noqa: E501

        :return: The recent_launch_failures of this SchedulerInfo.  # noqa: E501
        :rtype: list[MachineLaunchFailure]
        """
        return self._recent_launch_failures

    @recent_launch_failures.setter
    def recent_launch_failures(self, recent_launch_failures):
        """Sets the recent_launch_failures of this SchedulerInfo.

        Recent launch failures.  # noqa: E501

        :param recent_launch_failures: The recent_launch_failures of this SchedulerInfo.  # noqa: E501
        :type: list[MachineLaunchFailure]
        """
        if self.local_vars_configuration.client_side_validation and recent_launch_failures is None:  # noqa: E501
            raise ValueError("Invalid value for `recent_launch_failures`, must not be `None`")  # noqa: E501

        self._recent_launch_failures = recent_launch_failures

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchedulerInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SchedulerInfo):
            return True

        return self.to_dict() != other.to_dict()
